@@ -23,6 +23,9 @@
  */
 
 #include "config.h"
+// FIXME: "the following lines should be removed for stable releases"
+#undef PACKAGE
+#define PACKAGE "gchemutils-unstable" 
 #include <gcu/application.h>
 #include <gcu/element.h>
 #include <gcu/formula.h>
@@ -80,7 +83,7 @@ public:
 	GtkListStore *pclist;
 };
 
-GChemCalc::GChemCalc (): Application ("gchemcalc"),
+GChemCalc::GChemCalc (): Application ("gchemcalc-unstable"),
 formula ("")
 {
 }
@@ -498,8 +501,9 @@ int main (int argc, char *argv[])
 		argv ++;
 	}
 
+// FIXME "the following line should be edited for stable releases"
 	if (argc > 1) {
-		cout << _("For usage see: gchemcalc [-?|--help]") << endl;
+		cout << _("For usage see: gchemcalc-unstable [-?|--help]") << endl;
 		return -1;
 	}
 	
@@ -600,7 +604,7 @@ int main (int argc, char *argv[])
 	g_signal_connect (GTK_OBJECT (w), "activate",
 		 G_CALLBACK (cb_entry_active),
 		 window);
-	gcu_element_load_databases ((char*) "isotopes", NULL);
+	gcu_element_load_databases ("isotopes", NULL);
 	if (argc == 1){
 		gtk_entry_set_text (GTK_ENTRY (w), argv[0]);
 		cb_entry_active (GTK_ENTRY (w), window);
