@@ -43,26 +43,14 @@
 #include <libxml/xmlmemory.h>
 //#include <libgnomevfs/gnome-vfs-file-info.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
-#include <vector>
-#include <map>
-#ifdef HAVE_FSTREAM
-#	include <fstream>
-#else
-#	include <fstream.h>
-#endif
-#ifdef HAVE_OSTREAM
-#	include <ostream>
-#else
-#	include <ostream.h>
-#endif
-#ifdef HAVE_SSTREAM
-#	include <sstream>
-#else
-#	include <sstream.h>
-#endif
-#include <glib/gi18n.h>
 #include <clocale>
 #include <cmath>
+#include <vector>
+#include <map>
+#include <fstream>
+#include <ostream>
+#include <sstream>
+#include <glib/gi18n.h>
 
 #define SAVE	1
 #define LOAD	2
@@ -677,3 +665,8 @@ void gcDocument::RenameViews ()
 		window->ActivateActionWidget ("ui/MainToolbar/Save", !m_ReadOnly);
 	}
 }
+
+bool gcDocument::Import (const string &filename, const string& mime_type)
+{
+	return false;
+}
