@@ -2,9 +2,9 @@
 
 /* 
  * Gnome Crystal
- * bond.cc 
+ * line.cc 
  *
- * Copyright (C) 2000-2004 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2000-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -30,14 +30,6 @@
 #include <GL/glu.h>
 #include <cmath>
 
-static char *TypeName[] = {
-	(char*) "edges",
-	(char*) "diagonals",
-	(char*) "medians",
-	(char*) "bond",
-	(char*) "unique"
-};
-
 gcLine::gcLine(): CrystalLine()
 {
 }
@@ -54,7 +46,7 @@ bool gcLine::LoadOld(xmlNodePtr node, unsigned version)
 	if (txt)
 	{
 		int i = 0;
-		while (strcmp(txt, TypeName[i]) && (i < 5)) i++;
+		while (strcmp(txt, LineTypeName[i]) && (i < 5)) i++;
 		xmlFree(txt);
 		if (i < 5) m_nType = (CrystalLineType)i;
 		else return false;
